# SPDX-FileCopyrightText: © 2025 DSLab - Fondazione Bruno Kessler
#
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

from digitalhub.entities._commons.enums import EntityKinds
from digitalhub.entities.dataitem._base.builder import DataitemBuilder
from digitalhub.entities.dataitem.croissant.entity import DataitemCroissant
from digitalhub.entities.dataitem.croissant.spec import DataitemSpecCroissant, DataitemValidatorCroissant
from digitalhub.entities.dataitem.croissant.status import DataitemStatusCroissant


class DataitemCroissantBuilder(DataitemBuilder):
    """
    DataitemCroissant builder.
    """

    ENTITY_CLASS = DataitemCroissant
    ENTITY_SPEC_CLASS = DataitemSpecCroissant
    ENTITY_SPEC_VALIDATOR = DataitemValidatorCroissant
    ENTITY_STATUS_CLASS = DataitemStatusCroissant
    ENTITY_KIND = EntityKinds.DATAITEM_CROISSANT.value



# SPDX-FileCopyrightText: © 2025 DSLab - Fondazione Bruno Kessler
#
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

import typing

from digitalhub.entities.model._base.entity import Model

if typing.TYPE_CHECKING:
    from digitalhub.entities.model.huggingface.spec import ModelSpecHuggingface
    from digitalhub.entities.model.huggingface.status import ModelStatusHuggingface


class ModelHuggingface(Model):
    """
    ModelHuggingface class.
    """

    def __init__(self, *args, **kwargs) -> None:
        super().__init__(*args, **kwargs)

        self.spec: ModelSpecHuggingface
        self.status: ModelStatusHuggingface



# SPDX-FileCopyrightText: © 2025 DSLab - Fondazione Bruno Kessler
#
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

from digitalhub.entities.dataitem._base.spec import DataitemSpec, DataitemValidator


class DataitemSpecCroissant(DataitemSpec):
    """
    DataitemSpecCroissant specifications.
    """


class DataitemValidatorCroissant(DataitemValidator):
    """
    DataitemValidatorCroissant validator.
    """



# SPDX-FileCopyrightText: © 2025 DSLab - Fondazione Bruno Kessler
#
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

import typing
from typing import Any

from digitalhub.entities._commons.utils import refresh_decorator
from digitalhub.entities.dataitem._base.entity import Dataitem

if typing.TYPE_CHECKING:
    from digitalhub.entities.dataitem.croissant.spec import DataitemSpecCroissant
    from digitalhub.entities.dataitem.croissant.status import DataitemStatusCroissant


class DataitemCroissant(Dataitem):
    """
    DataitemCroissant class.
    """

    def __init__(self, *args, **kwargs) -> None:
        super().__init__(*args, **kwargs)

        self.spec: DataitemSpecCroissant
        self.status: DataitemStatusCroissant

    @refresh_decorator
    def as_dataset(self, **kwargs: Any) -> Any:
        raise NotImplementedError



# SPDX-FileCopyrightText: © 2025 DSLab - Fondazione Bruno Kessler
#
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

import typing

from digitalhub.entities.dataitem._base.entity import Dataitem

if typing.TYPE_CHECKING:
    from digitalhub.entities.dataitem.dataitem.spec import DataitemSpecDataitem
    from digitalhub.entities.dataitem.dataitem.status import DataitemStatusDataitem


class DataitemDataitem(Dataitem):
    """
    DataitemDataitem class.
    """

    def __init__(self, *args, **kwargs) -> None:
        super().__init__(*args, **kwargs)

        self.spec: DataitemSpecDataitem
        self.status: DataitemStatusDataitem



# SPDX-FileCopyrightText: © 2025 DSLab - Fondazione Bruno Kessler
#
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

from typing import Union

from digitalhub.stores.readers.data.types import _dataframe_types

SourcesOrListOfSources = str | list[str]

Dataframe = Union[_dataframe_types]



# SPDX-FileCopyrightText: © 2025 DSLab - Fondazione Bruno Kessler
#
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

import typing

from digitalhub.entities.model._base.entity import Model

if typing.TYPE_CHECKING:
    from digitalhub.entities.model.model.spec import ModelSpecModel
    from digitalhub.entities.model.model.status import ModelStatusModel


class ModelModel(Model):
    """
    ModelModel class.
    """

    def __init__(self, *args, **kwargs) -> None:
        super().__init__(*args, **kwargs)

        self.spec: ModelSpecModel
        self.status: ModelStatusModel



# SPDX-FileCopyrightText: © 2025 DSLab - Fondazione Bruno Kessler
#
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

import typing

from digitalhub.entities._base.material.entity import MaterialEntity
from digitalhub.entities._commons.enums import EntityTypes

if typing.TYPE_CHECKING:
    from digitalhub.entities.dataitem._base.spec import DataitemSpec
    from digitalhub.entities.dataitem._base.status import DataitemStatus


class Dataitem(MaterialEntity):
    """
    A class representing a dataitem.
    """

    ENTITY_TYPE = EntityTypes.DATAITEM.value

    def __init__(self, *args, **kwargs) -> None:
        super().__init__(*args, **kwargs)
        self.spec: DataitemSpec
        self.status: DataitemStatus
